<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../../about.ui" line="14"/>
        <source>About</source>
        <translation>عن</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="vanished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="25"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;PCManFM-Qt&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../about.ui" line="48"/>
        <source>Lightweight file manager</source>
        <translation>مدير ملفّات خفيف</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="58"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;http://lxqt.org/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://lxqt.org/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="87"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</source>
        <translation>المبرمجون:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;
</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="109"/>
        <source>PCManFM-Qt File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../about.ui" line="78"/>
        <source>Authors</source>
        <translation>المؤلّفون</translation>
    </message>
    <message>
        <source>PCMan File Manager

Copyright (C) 2009 - 2014 洪任諭 (Hong Jen Yee)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation type="vanished">مدير الملفّات PCMan

الحقوق محفوظة (C)‏ 2009 - 2014 洪任諭 ‏(Hong Jen Yee)

هذا البرنامج حر؛ بإمكانك إعادة توزيعه و/أو تعديله تحت شروط الرخصة العمومية العامة لجنو والتي نشرتها منظمة البرمجيات الحرة؛ سواء الإصدارة 2 من الرخصة أو أي إصدارة بعدها حسب رغبتك.

يوزّع هذا البرنامج على أمل أن يكون مفيدًا لمن يستخدمه، دون أدنى مسؤولية؛ ولا حتى أي ضمان يضمن صلاحية العرض في السوق أو توافقه مع أي استخدام محدد. يمكنك مراجعة الرخصة العمومية العامة لجنو لمزيد من التفاصيل.

من المفترض أن تكون قد استلمت نسخة من رخصة جنو العامة مع موسيقى جنوم؛ في حال عدم استلامك لذلك، يمكنك مكاتبة:
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
02110-1301 USA.</translation>
    </message>
    <message>
        <location filename="../../about.ui" line="100"/>
        <source>License</source>
        <translation>الرّخصة</translation>
    </message>
</context>
<context>
    <name>AutoRunDialog</name>
    <message>
        <location filename="../../autorun.ui" line="14"/>
        <source>Removable medium is inserted</source>
        <translation>أُدرج وسيط يمكن إزالته</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="33"/>
        <source>&lt;b&gt;Removable medium is inserted&lt;/b&gt;</source>
        <translation>&lt;b&gt;أُدرج وسيط يمكن إزالته&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="40"/>
        <source>Type of medium:</source>
        <translation>نوع الوسيط:</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="47"/>
        <source>Detecting...</source>
        <translation>يكتشف...</translation>
    </message>
    <message>
        <location filename="../../autorun.ui" line="56"/>
        <source>Please select the action you want to perform:</source>
        <translation>فضلًا اختر الإجراء الذي تريد تنفيذه:</translation>
    </message>
</context>
<context>
    <name>ConnectServerDialog</name>
    <message>
        <location filename="../../connect.ui" line="14"/>
        <source>Connect to remote server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="23"/>
        <source>Anonymous &amp;login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="36"/>
        <source>Login as &amp;user:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="65"/>
        <source>Specify remote folder to connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="72"/>
        <source>Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="79"/>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="86"/>
        <source>Path:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connect.ui" line="96"/>
        <source>Host:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DesktopFolder</name>
    <message>
        <location filename="../../desktop-folder.ui" line="14"/>
        <source>Form</source>
        <translation>نموذج</translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="23"/>
        <source>Desktop</source>
        <translation>سطح المكتب</translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="29"/>
        <source>Desktop folder:</source>
        <translation>مجلّد سطح المكتب:</translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="36"/>
        <source>Image file</source>
        <translation>ملفّ صورة</translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="42"/>
        <source>Folder path</source>
        <translation>مسار المجلّد</translation>
    </message>
    <message>
        <location filename="../../desktop-folder.ui" line="49"/>
        <source>&amp;Browse</source>
        <translation>ت&amp;صفّح</translation>
    </message>
</context>
<context>
    <name>DesktopPreferencesDialog</name>
    <message>
        <location filename="../../desktop-preferences.ui" line="14"/>
        <source>Desktop Preferences</source>
        <translation>تفضيلات سطح المكتب</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="30"/>
        <source>Background</source>
        <translation>الخلفيّة</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="52"/>
        <source>Wallpaper mode:</source>
        <translation>وضع الخلفيّة:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="65"/>
        <source>Wallpaper image file:</source>
        <translation>ملفّ صورة الخلفيّة:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="85"/>
        <source>Select background color:</source>
        <translation>اختر لون الخلفيّة:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="94"/>
        <source>Image file</source>
        <translation>ملفّ صورة</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="100"/>
        <source>Image file path</source>
        <translation>مسار ملفّ الصّورة</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="107"/>
        <source>&amp;Browse</source>
        <translation>ت&amp;صفّح</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="119"/>
        <source>Icons</source>
        <translation>الأيقونات</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="125"/>
        <source>Icon size:</source>
        <translation>حجم الأيقونة:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="138"/>
        <source>Label Text</source>
        <translation>نصوص اللصيقات</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="176"/>
        <source>Select  text color:</source>
        <translation>اختر لون النّصّ:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="189"/>
        <source>Select shadow color:</source>
        <translation>اختر ظلّ النّصّ:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="202"/>
        <source>Select font:</source>
        <translation>اختر الخطّ:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="24"/>
        <source>General</source>
        <translation>عامّ</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="225"/>
        <source>Spacing</source>
        <translation>التّباعد</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="231"/>
        <source>Minimum item margins:</source>
        <translation>أدنى هوامش للعناصر:</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="238"/>
        <source>3 px by default.</source>
        <translation>3 بكسل افتراضيًّا.</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="241"/>
        <location filename="../../desktop-preferences.ui" line="265"/>
        <source> px</source>
        <translation> بكسل</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="254"/>
        <source>x</source>
        <translation>×</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="261"/>
        <source>1 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation>بكسل واحد افتراضيًّا.
سيُحجز أيضًا مكان لنصّ بثلاث أسطر.</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="278"/>
        <source>Lock</source>
        <translation>اقفل</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="315"/>
        <source>Slide Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="321"/>
        <source>Enable Slide Show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="333"/>
        <source>Wallpaper image folder:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="340"/>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="347"/>
        <source> hour(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="357"/>
        <source>and</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="370"/>
        <source>Intervals less than 5min will be ignored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="373"/>
        <source>Interval:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="380"/>
        <source> minute(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="406"/>
        <source>Wallpaper folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="429"/>
        <source>Randomize the slide show</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="459"/>
        <source>Window Manager</source>
        <translation>مدير النّوافذ</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="465"/>
        <source>Show menus provided by window managers when desktop is clicked</source>
        <translation>أظهر القوائم التي يوفّرها مدير النّوافذ عند نقر سطح المكتب</translation>
    </message>
    <message>
        <location filename="../../desktop-preferences.ui" line="453"/>
        <source>Advanced</source>
        <translation>متقدّم</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../main-win.ui" line="14"/>
        <source>File Manager</source>
        <translation>مدير الملفّات</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="90"/>
        <source>Focus with Ctrl+I</source>
        <translation>ركّز باستخدام Ctrl+I</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="178"/>
        <source>&amp;Toolbars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="185"/>
        <source>Path &amp;Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="290"/>
        <source>Go &amp;Up</source>
        <translation>انتقل لأ&amp;على</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="293"/>
        <source>Go Up</source>
        <translation>انتقل لأعلى</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="296"/>
        <source>Alt+Up</source>
        <translation>Alt+Up</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="305"/>
        <source>&amp;Home</source>
        <translation>الم&amp;نزل</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="308"/>
        <source>Alt+Home</source>
        <translation>Alt+Home</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="317"/>
        <source>&amp;Reload</source>
        <translation>أ&amp;عد التّحميل</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="320"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="329"/>
        <source>Go</source>
        <translation>تنقّل</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="338"/>
        <source>Quit</source>
        <translation>أنهِ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="347"/>
        <source>&amp;About</source>
        <translation>&amp;عن</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="356"/>
        <source>&amp;New Window</source>
        <translation>نافذة &amp;جديدة</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="359"/>
        <source>New Window</source>
        <translation>نافذة جديدة</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="362"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="370"/>
        <source>Show &amp;Hidden</source>
        <translation>أظهر الم&amp;خفيّ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="373"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="382"/>
        <source>&amp;Computer</source>
        <translation>ال&amp;حاسوب</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="391"/>
        <source>&amp;Trash</source>
        <translation>الم&amp;هملات</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="396"/>
        <source>&amp;Network</source>
        <translation>ال&amp;شّبكة</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="405"/>
        <source>&amp;Desktop</source>
        <translation>س&amp;طح المكتب</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="414"/>
        <source>&amp;Add to Bookmarks</source>
        <translation>أ&amp;ضفض إلى العلامات</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="419"/>
        <source>&amp;Applications</source>
        <translation>التّطبي&amp;قات</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="424"/>
        <source>Reload</source>
        <translation>أعد التّحميل</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="432"/>
        <source>&amp;Icon View</source>
        <translation>منظور أي&amp;قوناتيّ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="440"/>
        <source>&amp;Compact View</source>
        <translation>منظور مترا&amp;صّ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="448"/>
        <source>&amp;Detailed List</source>
        <translation>منظور تف&amp;صيليّ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="456"/>
        <source>&amp;Thumbnail View</source>
        <translation>منظور مص&amp;غّراتيّ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="465"/>
        <source>Cu&amp;t</source>
        <translation>&amp;قصّ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="468"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="477"/>
        <source>&amp;Copy</source>
        <translation>ا&amp;نسخ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="480"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="489"/>
        <source>&amp;Paste</source>
        <translation>أل&amp;صق</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="492"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="497"/>
        <source>Select &amp;All</source>
        <translation>حدّد ال&amp;كلّ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="500"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="505"/>
        <source>Pr&amp;eferences</source>
        <translation>التّف&amp;ضيلات</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="513"/>
        <source>&amp;Ascending</source>
        <translation>ت&amp;صاعديًّا</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="521"/>
        <source>&amp;Descending</source>
        <translation>ت&amp;نازليًّا</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="529"/>
        <source>&amp;By File Name</source>
        <translation>باسم المل&amp;فّ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="537"/>
        <source>By &amp;Modification Time</source>
        <translation>بوقت التّ&amp;عديل</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="545"/>
        <source>By File &amp;Type</source>
        <translation>ب&amp;نوع الملفّ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="553"/>
        <source>By &amp;Owner</source>
        <translation>بال&amp;مالك</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="561"/>
        <source>&amp;Folder First</source>
        <translation>الم&amp;جلّدات أوّلًا</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="569"/>
        <source>&amp;Preserve sorting for this folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="668"/>
        <source>&amp;Case Sensitive</source>
        <translation>ح&amp;سّاس للحالة</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="676"/>
        <source>By File &amp;Size</source>
        <translation>بح&amp;جم الملفّ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="681"/>
        <source>&amp;Close Window</source>
        <translation>أ&amp;غلق النّافذة</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="684"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="716"/>
        <source>&amp;Folder</source>
        <translation>م&amp;جلّد</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="728"/>
        <source>&amp;Blank File</source>
        <translation>مل&amp;فّ فارغ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="747"/>
        <source>&amp;Filter</source>
        <translation>ر&amp;شّح</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="750"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="759"/>
        <source>Close &amp;previous tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="768"/>
        <source>Close &amp;next tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="807"/>
        <source>&amp;Preserve Settings for This Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="812"/>
        <source>Connect to &amp;Server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="820"/>
        <source>&amp;Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="828"/>
        <source>&amp;Path Buttons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close &amp;left tabs</source>
        <translation type="vanished">أغلق الألسنة على الي&amp;سار</translation>
    </message>
    <message>
        <source>Close &amp;right tabs</source>
        <translation type="vanished">أغلق الألسنة على الي&amp;مين</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="773"/>
        <source>Close &amp;other tabs</source>
        <translation>أغلق الألسنة الأ&amp;خرى</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="781"/>
        <source>&amp;Menu bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="784"/>
        <source>Menu bar</source>
        <translation>شريط القوائم</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="787"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="796"/>
        <location filename="../../main-win.ui" line="799"/>
        <source>Menu</source>
        <translation>القائمة</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="578"/>
        <source>New &amp;Tab</source>
        <translation>ل&amp;سان جديد</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="581"/>
        <source>New Tab</source>
        <translation>لسان جديد</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="584"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="593"/>
        <source>Go &amp;Back</source>
        <translation>&amp;عُد</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="596"/>
        <source>Go Back</source>
        <translation>عُد</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="599"/>
        <source>Alt+Left</source>
        <translation>Alt+Left</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="608"/>
        <source>Go &amp;Forward</source>
        <translation>ت&amp;قدّم</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="611"/>
        <source>Go Forward</source>
        <translation>تقدّم</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="614"/>
        <source>Alt+Right</source>
        <translation>Alt+Right</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="619"/>
        <source>&amp;Invert Selection</source>
        <translation>ا&amp;عكس التّحديد</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="628"/>
        <source>&amp;Delete</source>
        <translation>ا&amp;حذف</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="631"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="636"/>
        <source>&amp;Rename</source>
        <translation>أعد التّ&amp;سمية</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="639"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="644"/>
        <source>C&amp;lose Tab</source>
        <translation>أ&amp;غلق اللسان</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="647"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="652"/>
        <source>File &amp;Properties</source>
        <translation>&amp;خصائص الملفّ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="655"/>
        <source>Alt+Return</source>
        <translation>Alt+Enter</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="660"/>
        <source>&amp;Folder Properties</source>
        <translation>خصائص الم&amp;جلّد</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="689"/>
        <source>Edit Bookmarks</source>
        <translation>حرّر العلامات</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="694"/>
        <source>Open &amp;Terminal</source>
        <translation>افتح ال&amp;طّرفيّة</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="697"/>
        <source>F4</source>
        <translation>F4</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="702"/>
        <source>Open as &amp;Root</source>
        <translation>افتح ك&amp;جذر</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="707"/>
        <source>&amp;Edit Bookmarks</source>
        <translation>&amp;حرّر العلامات</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="719"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="731"/>
        <source>Ctrl+Alt+N</source>
        <translation>Ctrl+Alt+N</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="736"/>
        <source>&amp;Find Files</source>
        <translation>&amp;جِد ملفّات</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="739"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="93"/>
        <source>Filter by string...</source>
        <translation>رشّح حسب نصّ...</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="120"/>
        <source>&amp;File</source>
        <translation>&amp;ملفّ</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="124"/>
        <source>C&amp;reate New</source>
        <translation>أ&amp;نشئ جديدًا</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="142"/>
        <source>&amp;Help</source>
        <translation>م&amp;ساعدة</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="148"/>
        <location filename="../../main-win.ui" line="168"/>
        <source>&amp;View</source>
        <translation>من&amp;ظور</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="152"/>
        <source>&amp;Sorting</source>
        <translation>ال&amp;فرز</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="202"/>
        <source>&amp;Edit</source>
        <translation>ت&amp;حرير</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="217"/>
        <source>&amp;Bookmarks</source>
        <translation>&amp;علامات</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="224"/>
        <source>&amp;Go</source>
        <translation>تن&amp;قّل</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="241"/>
        <source>&amp;Tool</source>
        <translation>أ&amp;دوات</translation>
    </message>
    <message>
        <location filename="../../main-win.ui" line="261"/>
        <source>Main Toolbar</source>
        <translation>شريط الأدوات الرّئيسيّ</translation>
    </message>
</context>
<context>
    <name>PCManFM::Application</name>
    <message>
        <location filename="../../application.cpp" line="170"/>
        <source>Name of configuration profile</source>
        <translation>اسم تشكيلة الضّبط</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="170"/>
        <source>PROFILE</source>
        <translation>تّشكيلة</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="173"/>
        <source>Run PCManFM as a daemon</source>
        <translation>شغّل PCManFM كعفريت</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="176"/>
        <source>Quit PCManFM</source>
        <translation>أنهِ PCManFM</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="179"/>
        <source>Launch desktop manager</source>
        <translation>أطلق مدير سطح المكتب</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="182"/>
        <source>Turn off desktop manager if it&apos;s running</source>
        <translation>أوقف مدير سطح المكتب إن كان يعمل</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="185"/>
        <source>Open desktop preference dialog on the page with the specified name</source>
        <translation>افتح حواريّ تفضيلات سطح المكتب على الصّفحة بالاسم المحدّد</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="185"/>
        <location filename="../../application.cpp" line="200"/>
        <source>NAME</source>
        <translation>الاسم</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="188"/>
        <source>Open new window</source>
        <translation>افتح نافذة جديدة</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="191"/>
        <source>Open Find Files utility</source>
        <translation>افتح أداة إيجاد الملفّات</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="194"/>
        <source>Set desktop wallpaper from image FILE</source>
        <translation>اضبط خلفيّة سطح المكتب من ملفّ الصّورة FILE</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="194"/>
        <source>FILE</source>
        <translation>ملفّ</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="197"/>
        <source>MODE</source>
        <translation>وضع</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="197"/>
        <source>Set mode of desktop wallpaper. MODE=(%1)</source>
        <translation>اضبط وضع خلفيّة سطح المكتب. MODE=(%1)‎</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="200"/>
        <source>Open Preferences dialog on the page with the specified name</source>
        <translation>افتح حواريّ التفضيلات على الصّفحة بالاسم المحدّد</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="203"/>
        <source>Files or directories to open</source>
        <translation>الملفّات أو الأدلّة لفتحها</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="203"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[ملفّ1، ملفّ2،...]</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="540"/>
        <location filename="../../application.cpp" line="545"/>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="545"/>
        <source>Terminal emulator is not set.</source>
        <translation>محاكي الطّرفيّة غير مضبوط.</translation>
    </message>
</context>
<context>
    <name>PCManFM::AutoRunDialog</name>
    <message>
        <location filename="../../autorundialog.cpp" line="45"/>
        <source>Open in file manager</source>
        <translation>افتح في مدير الملفّات</translation>
    </message>
    <message>
        <location filename="../../autorundialog.cpp" line="136"/>
        <source>Removable Disk</source>
        <translation>قرص يمكن إزالته</translation>
    </message>
</context>
<context>
    <name>PCManFM::ConnectServerDialog</name>
    <message>
        <location filename="../../connectserverdialog.cpp" line="9"/>
        <source>SSH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="10"/>
        <source>FTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="11"/>
        <source>WebDav</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="12"/>
        <source>Secure WebDav</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="13"/>
        <source>HTTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../connectserverdialog.cpp" line="14"/>
        <source>HTTPS</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopPreferencesDialog</name>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="52"/>
        <source>Fill with background color only</source>
        <translation>املأ بلون الخلفيّة فقط</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="53"/>
        <source>Stretch to fill the entire screen</source>
        <translation>مدّد لملء الشّاشة كاملة</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="54"/>
        <source>Stretch to fit the screen</source>
        <translation>مدّد لتناسب الشّاشة</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="55"/>
        <source>Center on the screen</source>
        <translation>وسّط في الشّاشة</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="56"/>
        <source>Tile the image to fill the entire screen</source>
        <translation>كرّر الصّورة قطعًا لتملأ الشّاشة كاملة</translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="57"/>
        <source>Zoom the image to fill the entire screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../desktoppreferencesdialog.cpp" line="204"/>
        <source>Image Files</source>
        <translation>ملفّات الصّور</translation>
    </message>
</context>
<context>
    <name>PCManFM::DesktopWindow</name>
    <message>
        <location filename="../../desktopwindow.cpp" line="525"/>
        <source>Stic&amp;k to Current Position</source>
        <translation>ت&amp;شبّث بالمكان الحاليّ</translation>
    </message>
    <message>
        <location filename="../../desktopwindow.cpp" line="547"/>
        <source>Desktop Preferences</source>
        <translation>تفضيلات سطح المكتب</translation>
    </message>
</context>
<context>
    <name>PCManFM::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="264"/>
        <source>Clear text (Ctrl+K)</source>
        <translation>امح النّصّ (Ctrl+K)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="343"/>
        <source>Hide menu bar</source>
        <translation>أخفِ شريط القوائم</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="344"/>
        <source>This will hide the menu bar completely, use Ctrl+M to show it again.</source>
        <translation>سيخفي هذا شريط القوائم تمامًا، استخدم Ctrl+M لإظهاره مجدّدًا.</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="628"/>
        <source>Version: %1</source>
        <translation>الإصدارة: %1</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1263"/>
        <source>&amp;Move to Trash</source>
        <translation>ا&amp;نقل إلى المهملات</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1263"/>
        <source>&amp;Delete</source>
        <translation>ا&amp;حذف</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1332"/>
        <location filename="../../mainwindow.cpp" line="1340"/>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="1340"/>
        <source>Switch user command is not set.</source>
        <translation>لم يُضبط أمر تبديل المستخدم.</translation>
    </message>
</context>
<context>
    <name>PCManFM::PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.cpp" line="195"/>
        <source>Icon View</source>
        <translation>منظور أيقوناتيّ</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.cpp" line="196"/>
        <source>Compact View</source>
        <translation>منظور متراصّ</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.cpp" line="197"/>
        <source>Thumbnail View</source>
        <translation>منظور مصغّراتيّ</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.cpp" line="198"/>
        <source>Detailed List View</source>
        <translation>منظور قوائميّ مفصّل</translation>
    </message>
</context>
<context>
    <name>PCManFM::TabPage</name>
    <message>
        <location filename="../../tabpage.cpp" line="279"/>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <location filename="../../tabpage.cpp" line="292"/>
        <source>Free space: %1 (Total: %2)</source>
        <translation>المساحة الحرّة: %1 (المجموع: %2)</translation>
    </message>
    <message numerus="yes">
        <location filename="../../tabpage.cpp" line="309"/>
        <source>%n item(s)</source>
        <translation>
            <numerusform>لا عناصر</numerusform>
            <numerusform>عنصر واحد</numerusform>
            <numerusform>عنصران</numerusform>
            <numerusform>%n عناصر</numerusform>
            <numerusform>%n عنصرًا</numerusform>
            <numerusform>%n عنصر</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../tabpage.cpp" line="311"/>
        <source> (%n hidden)</source>
        <translation>
            <numerusform>(لا شيء مخفيّ)</numerusform>
            <numerusform>(واحد مخفيّ)</numerusform>
            <numerusform>(إثنان مخفيّان)</numerusform>
            <numerusform>(%n مخفيّة)</numerusform>
            <numerusform>(%n مخفيًّا)</numerusform>
            <numerusform>(%n مخفيّ)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../../tabpage.cpp" line="485"/>
        <source>%n item(s) selected</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 item(s) selected</source>
        <translatorcomment>معدود!</translatorcomment>
        <translation type="vanished">%1 من العناصر محدّد</translation>
    </message>
</context>
<context>
    <name>PCManFM::View</name>
    <message>
        <location filename="../../view.cpp" line="102"/>
        <source>Open in New T&amp;ab</source>
        <translation>افتح في ل&amp;سان جديد</translation>
    </message>
    <message>
        <location filename="../../view.cpp" line="106"/>
        <source>Open in New Win&amp;dow</source>
        <translation>افتح في &amp;نافذة جديدة</translation>
    </message>
    <message>
        <location filename="../../view.cpp" line="114"/>
        <source>Open in Termina&amp;l</source>
        <translation>افتح في ال&amp;طّرفية</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferences.ui" line="14"/>
        <source>Preferences</source>
        <translation>التّفضيلات</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="45"/>
        <source>User Interface</source>
        <translation>واجهة المستخدم</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="35"/>
        <source>Behavior</source>
        <translation>السّلوك</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="50"/>
        <location filename="../../preferences.ui" line="643"/>
        <source>Thumbnail</source>
        <translation>المصغّرات</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="55"/>
        <source>Volume</source>
        <translation>الأقراص</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="60"/>
        <source>Advanced</source>
        <translation>متقدّم</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="220"/>
        <source>Icons</source>
        <translation>الأيقونات</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="252"/>
        <source>Size of big icons:</source>
        <translation>مقاس الأيقونات الكبيرة:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="269"/>
        <source>Size of small icons:</source>
        <translation>مقاس الأيقونات الصّغيرة:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="286"/>
        <source>Size of thumbnails:</source>
        <translation>مقاس المصغّرات:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="300"/>
        <source>Size of side pane icons:</source>
        <translation>مقاس أيقونات الشّريط الجانبيّ:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="232"/>
        <source>Icon theme:</source>
        <translation>سمة الأيقونات:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="456"/>
        <source>Window</source>
        <translation>النّافذة</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="469"/>
        <source>Always show the tab bar</source>
        <translation>أظهر شريط الألسنة دائمًا</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="487"/>
        <source>Show &apos;Close&apos; buttons on tabs	</source>
        <translation>أظهر أزرار &quot;أغلق&quot; على الألسنة</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="494"/>
        <source>Remember the size of the last closed window</source>
        <translation>تذكّر حجم آخر نافذة مُغلقة</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="501"/>
        <source>Default width of new windows:</source>
        <translation>العرض الافتراضيّ للنّوافذ الجديدة:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="515"/>
        <source>Default height of new windows:</source>
        <translation>الارتفاع الافتراضيّ للنّوافذ الجديدة:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="81"/>
        <source>Browsing</source>
        <translation>التّصفّح</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="90"/>
        <source>Open files with single click</source>
        <translation>افتح الملفّات بنقرة واحدة</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="100"/>
        <source>Delay of auto-selection in single click mode (0 to disable)</source>
        <translation>تأخير التّحديد الآليّ في وضع النّقر المفرد (0 لتعطيله)</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="107"/>
        <source>Default view mode:</source>
        <translation>وضع المنظور الافتراضيّ:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="120"/>
        <source> sec</source>
        <translation> ثا</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="159"/>
        <source>File Operations</source>
        <translation>العمليّات على الملفّات</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="165"/>
        <source>Confirm before deleting files</source>
        <translation>أكّد قبل حذف الملفّات</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="172"/>
        <source>Move deleted files to &quot;trash bin&quot; instead of erasing from disk.</source>
        <translation>انقل الملفّات المحذوفة إلى &quot;سلّة المهملات&quot; بدل مسحها من القرص.</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="676"/>
        <source>Show thumbnails of files</source>
        <translation>أظهر مصغّرات للملفّات</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="666"/>
        <source>Only show thumbnails for local files</source>
        <translation>أظهر مصغّرات للملفّات المحليّة فقط</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="40"/>
        <source>Display</source>
        <translation>العرض</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="130"/>
        <source>Bookmarks:</source>
        <translation>العلامات:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="138"/>
        <source>Open in current tab</source>
        <translation>افتح في اللسان الحاليّ</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="143"/>
        <source>Open in new tab</source>
        <translation>افتح في لسان جديد</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="148"/>
        <source>Open in new window</source>
        <translation>افتح في نافذة جديدة</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="179"/>
        <source>Erase files on removable media instead of &quot;trash can&quot; creation</source>
        <translation>امسح الملفّات في الوسيط المنفصل بدل إنشاء &quot;سلة للمهملات&quot;</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="186"/>
        <source>Confirm before moving files into &quot;trash can&quot;</source>
        <translation>أكّد قبل نقل الملفّات إلى &quot;سلّة المهملات&quot;</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="193"/>
        <source>Don&apos;t ask options on launch executable file</source>
        <translation>لا تسأل عند إطلاق ملفّ تنفيذيّ</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="249"/>
        <location filename="../../preferences.ui" line="259"/>
        <source>Used by Icon View</source>
        <translation>يستخدمه المنظور الأيقوناتيّ</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="266"/>
        <location filename="../../preferences.ui" line="276"/>
        <source>Used by Compact View and Detailed List View</source>
        <translation>يستخدمه المنظورين المتراصّ والقوائميّ المفصّل</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="283"/>
        <location filename="../../preferences.ui" line="293"/>
        <source>Used by Thumbnail View</source>
        <translation>يستخدمه المنظور المصغّراتيّ</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="313"/>
        <source>User interface</source>
        <translation>واجهة المستخدم</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="326"/>
        <source>Treat backup files as hidden</source>
        <translation>عامِل ملفّات النّسخ الاحتياطيّ كمخفيّة</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="336"/>
        <source>Always show full file names</source>
        <translation>أظهر أسماء الملفّات كاملة دائمًا</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="346"/>
        <source>Show icons of hidden files shadowed</source>
        <translation>أظهر أيقونات الملفّات المخفيّة مظلّلة</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="369"/>
        <source>Minimum item margins in icon view:</source>
        <translation>أدنى هوامش للعناصر في المنظور الأيقوناتيّ:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="376"/>
        <source>3 px by default.</source>
        <translation>3 بكسل افتراضيًّا.</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="379"/>
        <location filename="../../preferences.ui" line="403"/>
        <source> px</source>
        <translation> بكسل</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="392"/>
        <source>x</source>
        <translation>×</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="399"/>
        <source>3 px by default.
A space is also reserved for 3 lines of text.</source>
        <translation>بكسل واحد افتراضيًّا.
سيُحجز أيضًا مكان لنصّ بثلاث أسطر.</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="416"/>
        <source>Lock</source>
        <translation>اقفل</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="465"/>
        <source>When unchecked, the tab bar will be shown
only if there are more than one tab.</source>
        <translation>إن لم يُؤشّر، فسيظهر شريط الألسنة فقط إن كان هناك أكثر من لسان واحد.</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="476"/>
        <source>If unchecked, the tab bar will be positioned only
above the folder-view and not above the left pane.</source>
        <translation>إن لم يُؤشّر، فسيكون شريط الألسنة موجودًا فوق منظور المجلّد فقط وليس فوق اللوحة اليمنى أيضًا.</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="480"/>
        <source>Fullwidth tab bar</source>
        <translation>شريط ألسنة كامل العرض</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="532"/>
        <source>Show in places</source>
        <translation>أظهر في الأماكن</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="539"/>
        <source>Home</source>
        <translation>المنزل</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="552"/>
        <source>Desktop</source>
        <translation>سطح المكتب</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="565"/>
        <source>Trash can</source>
        <translation>سلّة المهملات</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="578"/>
        <source>Computer</source>
        <translation>الحاسوب</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="591"/>
        <source>Applications</source>
        <translation>التّطبيقات</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="599"/>
        <source>Devices</source>
        <translation>الأجهزة</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="607"/>
        <source>Network</source>
        <translation>الشّبكة</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="649"/>
        <source>Do not generate thumbnails for image files exceeding this size:</source>
        <translation>لا تولّد مصغّرات لملفّات الصّور الأكبر من:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="656"/>
        <source> KB</source>
        <translation> ك.بايت</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="673"/>
        <source>Needs ffmpegthumbnailer</source>
        <translation>تحتاج المصغّرات ffmpegthumbnailer</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="703"/>
        <source>Auto Mount</source>
        <translation>الضّمّ الآليّ</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="709"/>
        <source>Mount mountable volumes automatically on program startup</source>
        <translation>ضُمّ الأقراص المنفصلة آليًّا عند بدء البرنامج</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="716"/>
        <source>Mount removable media automatically when they are inserted</source>
        <translation>ضُمّ آليًّا الوسيط المنفصل عندما يُدخل</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="723"/>
        <source>Show available options for removable media when they are inserted</source>
        <translation>أظهر الخيارات المتوفّرة للوسيط المنفصل عندما يُدخل</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="733"/>
        <source>When removable medium unmounted:</source>
        <translation>عند إزالة ضمّ وسيط منفصل:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="739"/>
        <source>Close &amp;tab containing removable medium</source>
        <translation>أغلق ال&amp;سان الذي فيه الوسيط المنفصل</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="746"/>
        <source>Chan&amp;ge folder in the tab to home folder</source>
        <translation>&amp;غيّر المجلّد في اللسان ليكون مجلّد المنزل</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="773"/>
        <source>Programs</source>
        <translation>البرامج</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="782"/>
        <source>Terminal emulator:</source>
        <translation>محاكي الطّرفيّة:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="789"/>
        <source>Switch &amp;user command:</source>
        <translation>أمر تبديل الم&amp;ستخدم:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="802"/>
        <source>Examples: &quot;xterm -e %s&quot; for terminal or &quot;gksu %s&quot; for switching user.
%s = the command line you want to execute with terminal or su.</source>
        <translation>أمثلة: &quot;xterm -e %s&quot; للطّرفيّة أو &quot;gksu %s&quot; لتبديل المستخدم.
‏‎%s = هو سطر الأوامر الذي ستنفّذه بالطّرفيّة أو su.</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="813"/>
        <source>Archiver in&amp;tegration:</source>
        <translation>ت&amp;كامل الأرشفة:</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="836"/>
        <source>Templates</source>
        <translation>القوالب</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="842"/>
        <source>Show only user defined templates in menu</source>
        <translation>أظهر القوالب التي عرّفها المستخدم فقط</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="849"/>
        <source>Show only one template for each MIME type</source>
        <translation>أظهر قالبًا واحدًا فقط لكلّ نوع MIME</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="856"/>
        <source>Run default application after creation from template</source>
        <translation>شغّل التّطبيق الافتراضيّ بعد الإنشاء من قالب</translation>
    </message>
    <message>
        <location filename="../../preferences.ui" line="319"/>
        <source>Use SI decimal prefixes instead of IEC binary prefixes</source>
        <translation>استخدم بادئات SI العشريّة بدل بادئات IEC الثّنائيّة</translation>
    </message>
</context>
</TS>
